diff --git a/src/main/resources/fess_config.properties b/src/main/resources/fess_config.properties
index 73b5c17f9..31674d03c 100644
--- a/src/main/resources/fess_config.properties
+++ b/src/main/resources/fess_config.properties
@@ -157,7 +157,7 @@ python.command.path=python
path.encoding=UTF-8
use.own.tmp.dir=true
max.log.output.length=4000
-adaptive.load.control=0
+adaptive.load.control=50
supported.uploaded.js.extentions=js
supported.uploaded.css.extentions=css
supported.uploaded.media.extentions=jpg,jpeg,gif,png,swf
diff --git a/src/main/java/org/codelibs/fess/mylasta/direction/FessConfig.java b/src/main/java/org/codelibs/fess/mylasta/direction/FessConfig.java
index 68a050cec..16d87ce78 100644
--- a/src/main/java/org/codelibs/fess/mylasta/direction/FessConfig.java
+++ b/src/main/java/org/codelibs/fess/mylasta/direction/FessConfig.java
@@ -211,7 +211,7 @@ public interface FessConfig extends FessEnv, org.codelibs.fess.mylasta.direction
/** The key of the configuration. e.g. 4000 */
String MAX_LOG_OUTPUT_LENGTH = "max.log.output.length";
/** The key of the configuration. e.g. 0 */
String ADAPTIVE_LOAD_CONTROL = "adaptive.load.control";
/** The key of the configuration. e.g. js */
@@ -2164,14 +2164,14 @@ public interface FessConfig extends FessEnv, org.codelibs.fess.mylasta.direction
/**
* Get the value for the key 'adaptive.load.control'.
- * The value is, e.g. 0
+ * The value is, e.g. 50
* @return The value of found property. (NotNull: if not found, exception but basically no way)
*/
String getAdaptiveLoadControl();
/**
* Get the value for the key 'adaptive.load.control' as {@link Integer}.
- * The value is, e.g. 0
+ * The value is, e.g. 50
* @return The value of found property. (NotNull: if not found, exception but basically no way)
* @throws NumberFormatException When the property is not integer.
*/
@@ -10476,7 +10476,7 @@ public interface FessConfig extends FessEnv, org.codelibs.fess.mylasta.direction
defaultMap.put(FessConfig.PATH_ENCODING, "UTF-8");
defaultMap.put(FessConfig.USE_OWN_TMP_DIR, "true");
defaultMap.put(FessConfig.MAX_LOG_OUTPUT_LENGTH, "4000");
- defaultMap.put(FessConfig.ADAPTIVE_LOAD_CONTROL, "0");
+ defaultMap.put(FessConfig.ADAPTIVE_LOAD_CONTROL, "50");
defaultMap.put(FessConfig.SUPPORTED_UPLOADED_JS_EXTENTIONS, "js");
defaultMap.put(FessConfig.SUPPORTED_UPLOADED_CSS_EXTENTIONS, "css");
defaultMap.put(FessConfig.SUPPORTED_UPLOADED_MEDIA_EXTENTIONS, "jpg,jpeg,gif,png,swf");
@@ -211,7 +211,7 @@ public interface FessConfig extends FessEnv, org.codelibs.fess.mylasta.direction
/** The key of the configuration. e.g. 4000 */
String MAX_LOG_OUTPUT_LENGTH = "max.log.output.length";
- /** The key of the configuration. e.g. 0 */
+ /** The key of the configuration. e.g. 50 */
String ADAPTIVE_LOAD_CONTROL = "adaptive.load.control";
/** The key of the configuration. e.g. js */